@@ -1,6 +1,3 @@
-from robot.api import logger  # type: ignore
-
-
 class LibraryComponent:
     def __init__(self, library):
         """Base class exposing attributes from the common context.
@@ -10,12 +7,6 @@ class LibraryComponent:
         """
         self.library = library
 
-    def info(self, msg: str, html=False):
-        logger.info(msg, html)
-
-    def debug(self, msg: str, html=False):
-        logger.debug(msg, html)
-
     @property
     def playwright(self):
         return self.library.playwright
