@@ -1,61 +1,53 @@
-from typing import Optional, Union
-
 from robotlibcore import keyword  # type: ignore
 
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
 from ..utils.time_conversion import timestr_to_millisecs
+from ..utils import logger
 
 
 class Control(LibraryComponent):
     """Keywords to do things on the current browser page and modify the page
     """
 
-    def __init__(self, library):
-        self.library = library
-
-    @property
-    def playwright(self):
-        return self.library.playwright
-
-    @keyword
+    @keyword(tags=["BrowserControl"])
     def go_forward(self):
         """Navigates to the next page in history."""
         with self.playwright.grpc_channel() as stub:
             response = stub.GoForward(Request.Empty())
-            self.info(response.log)
+            logger.info(response.log)
 
-    @keyword
+    @keyword(tags=["BrowserControl"])
     def go_back(self):
         """Navigates to the previous page in history."""
         with self.playwright.grpc_channel() as stub:
             response = stub.GoBack(Request.Empty())
-            self.info(response.log)
+            logger.info(response.log)
 
-    @keyword
+    @keyword(tags=["BrowserControl"])
     def go_to(self, url: str):
         """Navigates to the given ``url``."""
         with self.playwright.grpc_channel() as stub:
             response = stub.GoTo(Request().Url(url=url))
-            self.info(response.log)
+            logger.info(response.log)
 
     @keyword
-    def take_page_screenshot(self, path: Optional[str] = None):
+    def take_page_screenshot(self, path: str = ""):
         """Takes screenshot of the current window and saves it to ``path``.
 
         The default path is the Robot Framework output directory.
         """
-        if path is None:
+        if not path:
             path = self.library.get_screenshot_path
-        self.info(f"Taking screenshot into ${path}")
+        logger.info(f"Taking screenshot into ${path}")
         with self.playwright.grpc_channel() as stub:
             response = stub.TakeScreenshot(Request().ScreenshotPath(path=path))
-            self.info(
+            logger.info(
                 f"Saved screenshot in <a href='file://{response.body}''>{response.body}</a>",
                 html=True,
             )
 
-    @keyword
+    @keyword(tags=["BrowserControl"])
     def set_timeout(self, timeout: str):
         """Sets the timeout used by most input and getter keywords.
 
@@ -64,9 +56,9 @@ class Control(LibraryComponent):
         parsed_timeout = timestr_to_millisecs(timeout)
         with self.playwright.grpc_channel() as stub:
             response = stub.SetTimeout(Request().Timeout(timeout=parsed_timeout))
-            self.info(response.log)
+            logger.info(response.log)
 
-    @keyword
+    @keyword(tags=["PageContent"])
     def add_style_tag(self, content: str):
         """Adds a <style type="text/css"> tag with the content.
 
@@ -74,10 +66,10 @@ class Control(LibraryComponent):
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.AddStyleTag(Request().StyleTag(content=content))
-            self.info(response.log)
+            logger.info(response.log)
 
-    @keyword
-    def highlight_element(self, selector: str, duration: Union[str, int] = "5s"):
+    @keyword(tags=["PageContent"])
+    def highlight_element(self, selector: str, duration: str = "5s"):
         """Adds a red highlight to elements matched by ``selector`` for ``duration``"""
         with self.playwright.grpc_channel() as stub:
             duration_ms = timestr_to_millisecs(duration)
@@ -86,21 +78,23 @@ class Control(LibraryComponent):
                     selector=selector, duration=duration_ms
                 )
             )
-            self.info(response.log)
+            logger.info(response.log)
 
-    @keyword
-    def switch_active_page(self, index: int):
-        """Switches the active browser page to another open page by ``index``.
+    @keyword(tags=["BrowserControl"])
+    def set_viewport_size(self, width: int, height: int):
+        """Sets current Pages viewport size to specified dimensions.
 
-            Newly opened pages get appended to the end of the list
-        """
+        In the case of multiple pages in a single browser,
+        each page can have its own viewport size. However,
+        `New Context` allows to set viewport size (and more) for all
+        later opened pages in the context at once.
+
+        `Set Viewport Size` will resize the page.
+        A lot of websites don't expect phones to change size,
+        so you should set the viewport size before navigating to
+        the page with `New Context` before opening the page itself."""
         with self.playwright.grpc_channel() as stub:
-            response = stub.SwitchActivePage(Request().Index(index=index))
-            self.info(response.log)
-
-    @keyword
-    def auto_activate_pages(self):
-        """Toggles automatically changing active page to latest opened page """
-        with self.playwright.grpc_channel() as stub:
-            response = stub.AutoActivatePages(Request().Empty())
-            self.info(response.log)
+            response = stub.SetViewportSize(
+                Request().Viewport(height=height, width=width)
+            )
+            logger.info(response.log)
