@@ -2,11 +2,12 @@ import json
 from enum import Enum, auto
 
 from robotlibcore import keyword  # type: ignore
-from typing import Optional, Dict
+from typing import Dict
 
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
 from ..utils.time_conversion import timestr_to_millisecs
+from ..utils import logger
 
 
 class ElementState(Enum):
@@ -17,12 +18,12 @@ class ElementState(Enum):
 
 
 class Waiter(LibraryComponent):
-    @keyword
+    @keyword(tags=["Wait", "PageContent"])
     def wait_for_elements_state(
         self,
         selector: str,
         state: ElementState = ElementState.visible,
-        timeout: Optional[str] = None,
+        timeout: str = "",
     ):
         """Waits for the element found by ``selector`` to satisfy state option.
 
@@ -54,4 +55,4 @@ class Waiter(LibraryComponent):
                     selector=selector, options=options_json
                 )
             )
-            self.info(response.log)
+            logger.info(response.log)
