@@ -6,11 +6,12 @@ from robotlibcore import keyword  # type: ignore
 from ..assertion_engine import AssertionOperator, verify_assertion
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
+from ..utils import logger
 
 
 class WebAppState(LibraryComponent):
-    @keyword
-    def local_storage_get(
+    @keyword(name="localStorage get Item", tags=["WebAppState", "Assertion", "Getter"])
+    def local_storage_get_item(
         self,
         key: str,
         assertion_operator: Optional[AssertionOperator] = None,
@@ -23,16 +24,16 @@ class WebAppState(LibraryComponent):
             response = stub.ExecuteJavascriptOnPage(
                 Request().JavascriptCode(script=f'window.localStorage.getItem("{key}")')
             )
-            self.info(response.log)
-        return verify_assertion(
-            json.loads(response.result),
-            assertion_operator,
-            assertion_expected,
-            "localStorage ",
-        )
+            logger.info(response.log)
+            return verify_assertion(
+                json.loads(response.result),
+                assertion_operator,
+                assertion_expected,
+                "localStorage ",
+            )
 
-    @keyword
-    def local_storage_set(self, key: str, value: str):
+    @keyword(name="localStorage set Item", tags=["WebAppState"])
+    def local_storage_set_item(self, key: str, value: str):
         """
         Save data to localStorage
         """
@@ -42,10 +43,10 @@ class WebAppState(LibraryComponent):
                     script=f'window.localStorage.setItem("{key}", "{value}")'
                 )
             )
-            self.info(response.log)
+            logger.info(response.log)
 
-    @keyword
-    def local_storage_remove(self, key: str):
+    @keyword(name="localStorage remove Item", tags=["WebAppState"])
+    def local_storage_remove_item(self, key: str):
         """
         Remove saved data with key from localStorage
         """
@@ -55,9 +56,9 @@ class WebAppState(LibraryComponent):
                     script=f'window.localStorage.removeItem("{key}")'
                 )
             )
-            self.info(response.log)
+            logger.info(response.log)
 
-    @keyword
+    @keyword(name="localStorage clear", tags=["WebAppState"])
     def local_storage_clear(self):
         """
         Remove all saved data from localStorage
@@ -66,10 +67,12 @@ class WebAppState(LibraryComponent):
             response = stub.ExecuteJavascriptOnPage(
                 Request().JavascriptCode(script="window.localStorage.clear()")
             )
-            self.info(response.log)
+            logger.info(response.log)
 
-    @keyword
-    def session_storage_get(
+    @keyword(
+        name="sessionStorage get Item", tags=["WebAppState", "Assertion", "Getter"]
+    )
+    def session_storage_get_item(
         self,
         key: str,
         assertion_operator: Optional[AssertionOperator] = None,
@@ -84,16 +87,16 @@ class WebAppState(LibraryComponent):
                     script=f'window.sessionStorage.getItem("{key}")'
                 )
             )
-            self.info(response.log)
-        return verify_assertion(
-            json.loads(response.result),
-            assertion_operator,
-            assertion_expected,
-            "sessionStorage ",
-        )
+            logger.info(response.log)
+            return verify_assertion(
+                json.loads(response.result),
+                assertion_operator,
+                assertion_expected,
+                "sessionStorage ",
+            )
 
-    @keyword
-    def session_storage_set(self, key: str, value: str):
+    @keyword(name="sessionStorage set Item", tags=["WebAppState"])
+    def session_storage_set_item(self, key: str, value: str):
         """
         Save data to sessionStorage
         """
@@ -103,10 +106,10 @@ class WebAppState(LibraryComponent):
                     script=f'window.sessionStorage.setItem("{key}", "{value}")'
                 )
             )
-            self.info(response.log)
+            logger.info(response.log)
 
-    @keyword
-    def session_storage_remove(self, key: str):
+    @keyword(name="sessionStorage remove Item", tags=["WebAppState"])
+    def session_storage_remove_item(self, key: str):
         """
         Remove saved data with key from sessionStorage
         """
@@ -116,9 +119,9 @@ class WebAppState(LibraryComponent):
                     script=f'window.sessionStorage.removeItem("{key}")'
                 )
             )
-            self.info(response.log)
+            logger.info(response.log)
 
-    @keyword
+    @keyword(name="sessionStorage clear", tags=["WebAppState"])
     def session_storage_clear(self):
         """
         Remove all saved data from sessionStorage
@@ -127,4 +130,4 @@ class WebAppState(LibraryComponent):
             response = stub.ExecuteJavascriptOnPage(
                 Request().JavascriptCode(script="window.sessionStorage.clear()")
             )
-            self.info(response.log)
+            logger.info(response.log)
