@@ -6,12 +6,12 @@ from subprocess import Popen, STDOUT
 import time
 
 import grpc  # type: ignore
-from robot.api import logger  # type: ignore
-from robot.libraries.BuiltIn import BuiltIn  # type: ignore
+from robot.libraries.BuiltIn import BuiltIn, EXECUTION_CONTEXTS  # type: ignore
 
 from Browser.generated.playwright_pb2 import Request
 import Browser.generated.playwright_pb2_grpc as playwright_pb2_grpc
 from Browser.utils.time_conversion import timestr_to_millisecs
+from Browser.utils import logger
 
 
 class Playwright:
@@ -23,7 +23,10 @@ class Playwright:
 
     @property
     def outputdir(self):
-        return BuiltIn().get_variable_value("${OUTPUTDIR}")
+        if EXECUTION_CONTEXTS.current:
+            return BuiltIn().get_variable_value("${OUTPUTDIR}")
+        else:
+            return "."
 
     @functools.cached_property
     def _playwright_process(self) -> Popen:
@@ -98,11 +101,18 @@ class Playwright:
             pass
         try:
             return err.details()
+        except TypeError:
+            return err.details
         except AttributeError:
             pass
         return str(err)
 
     def close(self):
+        logger.debug("Closing all open browsers, contexts and pages in Playwright")
+        with self.grpc_channel() as stub:
+            response = stub.CloseAllBrowsers(Request().Empty())
+            logger.info(response.log)
+
         logger.debug("Closing Playwright process")
         self._playwright_process.kill()
         logger.debug("Playwright process killed")
