@@ -1,7 +1,5 @@
-from typing import Union
-
 from robot.utils import timestr_to_secs  # type: ignore
 
 
-def timestr_to_millisecs(time_str: Union[Union[int, str], float]) -> int:
+def timestr_to_millisecs(time_str: str) -> int:
     return timestr_to_secs(time_str) * 1000
